@@ -21,9 +21,6 @@
 #include "config.h"
 #include <calf/ctl_tube.h>
 #include <cairo/cairo.h>
-#if !defined(__APPLE__)
-#include <malloc.h>
-#endif
 #include <math.h>
 #include <stdint.h>
 #include <stdlib.h>
@@ -321,17 +318,18 @@ calf_tube_get_type (void)
         };
         
         for (int i = 0; ; i++) {
-            char *name = g_strdup_printf("CalfTube%u%d", 
-                ((unsigned int)(intptr_t)calf_tube_class_init) >> 16, i);
+            const char *name = "CalfTube";
+            //char *name = g_strdup_printf("CalfTube%u%d", 
+                //((unsigned int)(intptr_t)calf_tube_class_init) >> 16, i);
             if (g_type_from_name(name)) {
-                free(name);
+                //free(name);
                 continue;
             }
             type = g_type_register_static( GTK_TYPE_DRAWING_AREA,
                                            name,
                                            &type_info,
                                            (GTypeFlags)0);
-            free(name);
+            //free(name);
             break;
         }
     }
