@@ -19,41 +19,38 @@
  * Boston, MA  02110-1301  USA
  */
 
-#include "config.h"
-#include <calf/primitives.h>
 #include <calf/ctl_vumeter.h>
-#include <gdk/gdkkeysyms.h>
-#include <cairo/cairo.h>
-#include <math.h>
-#include <gdk/gdk.h>
-#include <sys/time.h>
-#include <string>
 
 
 ///////////////////////////////////////// vu meter ///////////////////////////////////////////////
 
+
 static gboolean
 calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
 {
     g_assert(CALF_IS_VUMETER(widget));
 
     CalfVUMeter *vu = CALF_VUMETER(widget);
-    GtkStyle    *style;
-    style = gtk_widget_get_style(widget);
     cairo_t *c = gdk_cairo_create(GDK_DRAWABLE(widget->window));
     
-    int width = widget->allocation.width; int height = widget->allocation.height;
-    int border_x = 1; int border_y = 1; // outer border
+    float r, g, b;
+    
+    int x = widget->allocation.x;
+    int y = widget->allocation.y;
+    int width = widget->allocation.width;
+    int height = widget->allocation.height;
+    int border_x = widget->style->xthickness;
+    int border_y = widget->style->ythickness;
     int space_x = 1; int space_y = 1; // inner border around led bar
     int led = 2; // single LED size
     int led_m = 1; // margin between LED
     int led_s = led + led_m; // size of LED with margin
-    int led_x = 5; int led_y = 4; // position of first LED
+    int led_x = widget->style->xthickness;
+    int led_y = widget->style->ythickness; // position of first LED
     int led_w = width - 2 * led_x + led_m; // width of LED bar w/o text calc (additional led margin, is removed later; used for filling the led bar completely w/o margin gap)
     int led_h = height - 2 * led_y; // height of LED bar w/o text calc
     int text_x = 0; int text_y = 0;
     int text_w = 0; int text_h = 0;
-    int text_m = 3; // text margin
 
     // only valid if vumeter is enabled
     cairo_text_extents_t extents;
@@ -68,25 +65,25 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
         switch(vu->vumeter_position) {
             case 1:
                 text_x = width / 2 - text_w / 2;
-                text_y = border_y + text_m - extents.y_bearing;
-                led_y += text_h + text_m;
-                led_h -= text_h + text_m;
+                text_y = border_y + led_y - extents.y_bearing;
+                led_y += text_h + led_y;
+                led_h -= text_h + led_y;
                 break;
             case 2:
-                text_x = width - border_x - text_m * 2 - text_w;
+                text_x = width - border_x - led_x - text_w;
                 text_y = height / 2 - text_h / 2 - extents.y_bearing;
-                led_w -= text_m * 2 + text_w;
+                led_w -= led_x + text_w;
                 break;
             case 3:
                 text_x = width / 2 - text_w / 2;
-                text_y = height - border_y - text_m - text_h - extents.y_bearing;
-                led_h -= text_m * 2 + text_h;
+                text_y = height - border_y - led_y - text_h - extents.y_bearing;
+                led_h -= led_y + text_h;
                 break;
             case 4:
-                text_x = border_x + text_m;
+                text_x = border_x + led_x;
                 text_y = height / 2 - text_h / 2 - extents.y_bearing;
-                led_x += text_m * 2 + text_w;
-                led_w -= text_m * 2 + text_w;
+                led_x += led_x + text_w;
+                led_w -= led_x + text_w;
                 break;
         }
     }
@@ -96,48 +93,27 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
     if( vu->cache_surface == NULL ) {
         // looks like its either first call or the widget has been resized.
         // create the cache_surface.
-        cairo_surface_t *window_surface = cairo_get_target( c );
-        vu->cache_surface = cairo_surface_create_similar( window_surface, 
-                                  CAIRO_CONTENT_COLOR,
-                                  widget->allocation.width,
-                                  widget->allocation.height );
-
-        // And render the meterstuff
-
+        vu->cache_surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height );
         cairo_t *cache_cr = cairo_create( vu->cache_surface );
-        gdk_cairo_set_source_color(cache_cr,&style->bg[GTK_STATE_NORMAL]);
-        cairo_paint(cache_cr);
         
-        // outer (black)
-        cairo_rectangle(cache_cr, 0, 0, width, height);
-        cairo_set_source_rgb(cache_cr, 0, 0, 0);
+        float radius, bevel, glass;
+        get_bg_color(widget, NULL, &r, &g, &b);
+        gtk_widget_style_get(widget, "border-radius", &radius, "bevel",  &bevel, "glass", &glass, NULL);
+        create_rectangle(cache_cr, 0, 0, width, height, radius);
+        cairo_set_source_rgb(cache_cr, r, g, b);
         cairo_fill(cache_cr);
-        
-        // inner (bevel)
-        cairo_rectangle(cache_cr,
-                        border_x,
-                        border_y,
-                        width - border_x * 2,
-                        height - border_y * 2);
-        cairo_pattern_t *pat2 = cairo_pattern_create_linear (border_x,
-                                                             border_y,
-                                                             border_x,
-                                                             height - border_y * 2);
-        cairo_pattern_add_color_stop_rgba (pat2, 0, 0.23, 0.23, 0.23, 1);
-        cairo_pattern_add_color_stop_rgba (pat2, 0.5, 0, 0, 0, 1);
-        cairo_set_source (cache_cr, pat2);
-        cairo_fill(cache_cr);
-        cairo_pattern_destroy(pat2);
+        draw_bevel(cache_cr, 0, 0, width, height, radius, bevel);
         
         // border around LED
-        cairo_rectangle(cache_cr,
-                        led_x - space_x,
-                        led_y - space_y,
-                        led_w + space_x * 2,
-                        led_h + space_y * 2);
+        cairo_rectangle(cache_cr, led_x, led_y, led_w, led_h);
         cairo_set_source_rgb (cache_cr, 0, 0, 0);
         cairo_fill(cache_cr);
         
+        led_x += space_x;
+        led_y += space_y;
+        led_w -= 2 * space_x;
+        led_h -= 2 * space_y;
+        
         // LED bases
         cairo_set_line_width(cache_cr, 1);
         for (int x = led_x; x + led <= led_x + led_w; x += led_s)
@@ -208,18 +184,17 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
         }
         // create blinder pattern
         cairo_pattern_t *pat = cairo_pattern_create_linear (led_x, led_y, led_x, led_y + led_h);
-        cairo_pattern_add_color_stop_rgba (pat, 0, 1, 1, 1, 0.25);
-        cairo_pattern_add_color_stop_rgba (pat, 0.5, 0.5, 0.5, 0.5, 0.0);
-        cairo_pattern_add_color_stop_rgba (pat, 1, 0.0, 0.0, 0.0, 0.25);
-        cairo_rectangle(cache_cr, led_x, led_y, led_w, led_h);
-        cairo_set_source(cache_cr, pat);
-        cairo_fill(cache_cr);
+        if (glass > 0.f) {
+            cairo_pattern_add_color_stop_rgba (pat, 0, 1, 1, 1, 0.25 * glass);
+            cairo_pattern_add_color_stop_rgba (pat, 0.5, 0.5, 0.5, 0.5, 0.0);
+            cairo_pattern_add_color_stop_rgba (pat, 1, 0.0, 0.0, 0.0, 0.25 * glass);
+            cairo_rectangle(cache_cr, led_x, led_y, led_w, led_h);
+            cairo_set_source(cache_cr, pat);
+            cairo_fill(cache_cr);
+        }
         
         // create overlay
-        vu->cache_overlay = cairo_surface_create_similar(window_surface, 
-                                  CAIRO_CONTENT_COLOR,
-                                  widget->allocation.width,
-                                  widget->allocation.height);
+        vu->cache_overlay = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height);
         cairo_t *over_cr = cairo_create(vu->cache_overlay);
         
         // copy surface to overlay
@@ -229,10 +204,11 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
         
         // create blinder pattern
         pat = cairo_pattern_create_linear (led_x, led_y, led_x, led_y + led_h);
-        cairo_pattern_add_color_stop_rgba (pat, 0, 0.2, 0.2, 0.2, 0.7);
+        float c1 = 0.05 + 0.15 * glass;
+        cairo_pattern_add_color_stop_rgba (pat, 0, c1, c1, c1, 0.7);
         cairo_pattern_add_color_stop_rgba (pat, 0.4, 0.05, 0.05, 0.05, 0.7);
-        cairo_pattern_add_color_stop_rgba (pat, 0.401, 0.05, 0.05, 0.05, 0.9);
-        cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.05, 0.75);
+        cairo_pattern_add_color_stop_rgba (pat, 0.401, 0.05, 0.05, 0.05, 0.7 + 0.2 * glass);
+        cairo_pattern_add_color_stop_rgba (pat, 1, 0.05, 0.05, 0.05, 0.7 + 0.05 * glass);
         
         // draw on top of overlay
         cairo_set_source(over_cr, pat);
@@ -242,12 +218,20 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
         // clean up
         cairo_destroy(cache_cr);
         cairo_destroy(over_cr);
+    } else {
+        led_x += space_x;
+        led_y += space_y;
+        led_w -= 2 * space_x;
+        led_h -= 2 * space_y;
     }
-    
+    led_x += x;
+    led_y += y;
+    text_x += x;
+    text_y += y;
     // draw LED blinder
-    cairo_set_source_surface( c, vu->cache_surface, 0,0 );
+    cairo_set_source_surface( c, vu->cache_surface, x, y );
     cairo_paint( c );
-    cairo_set_source_surface( c, vu->cache_overlay, 0, 0 );
+    cairo_set_source_surface( c, vu->cache_overlay, x, y );
     
     // get microseconds
     timeval tv;
@@ -371,10 +355,13 @@ calf_vumeter_expose (GtkWidget *widget, GdkEventExpose *event)
         // draw value as number
         cairo_text_extents(c, str, &extents);
         cairo_move_to(c, text_x + (text_w - extents.width) / 2.0, text_y);
+        GtkStateType state;
         if(vu->disp_value > 1.f and vu->mode != VU_MONOCHROME_REVERSE)
-            cairo_set_source_rgba (c, 1, 0, 0, 0.8);
+            state = GTK_STATE_ACTIVE;
         else
-            cairo_set_source_rgba (c, 0, 0.9, 1, 0.8);
+            state = GTK_STATE_NORMAL;
+        get_fg_color(widget, &state, &r, &g, &b);
+        cairo_set_source_rgba (c, r, g, b, 1);
         cairo_show_text(c, str);
         cairo_fill(c);
     }
@@ -427,6 +414,15 @@ calf_vumeter_class_init (CalfVUMeterClass *klass)
     widget_class->expose_event = calf_vumeter_expose;
     widget_class->size_request = calf_vumeter_size_request;
     widget_class->size_allocate = calf_vumeter_size_allocate;
+    gtk_widget_class_install_style_property(
+        widget_class, g_param_spec_float("border-radius", "Border Radius", "Generate round edges",
+        0, 24, 4, GParamFlags(G_PARAM_READWRITE)));
+    gtk_widget_class_install_style_property(
+        widget_class, g_param_spec_float("bevel", "Bevel", "Bevel the object",
+        -2, 2, 0.2, GParamFlags(G_PARAM_READWRITE)));
+    gtk_widget_class_install_style_property(
+        widget_class, g_param_spec_float("glass", "Glass", "Glass effect on top",
+        0, 1, 1, GParamFlags(G_PARAM_READWRITE)));
 }
 
 static void
@@ -442,6 +438,7 @@ calf_vumeter_init (CalfVUMeter *self)
     self->meter_width = 0;
     self->disp_value = 0.f;
     self->value = 0.f;
+    gtk_widget_set_has_window(widget, FALSE);
     g_signal_connect(GTK_OBJECT(widget), "unrealize", G_CALLBACK(calf_vumeter_unrealize), (gpointer)self);
 }
 
@@ -471,16 +468,17 @@ calf_vumeter_get_type (void)
         GTypeInfo *type_info_copy = new GTypeInfo(type_info);
 
         for (int i = 0; ; i++) {
-            char *name = g_strdup_printf("CalfVUMeter%u%d", ((unsigned int)(intptr_t)calf_vumeter_class_init) >> 16, i);
+            const char *name = "CalfVUMeter";
+            //char *name = g_strdup_printf("CalfVUMeter%u%d", ((unsigned int)(intptr_t)calf_vumeter_class_init) >> 16, i);
             if (g_type_from_name(name)) {
-                free(name);
+                //free(name);
                 continue;
             }
             type = g_type_register_static( GTK_TYPE_DRAWING_AREA,
                                            name,
                                            type_info_copy,
                                            (GTypeFlags)0);
-            free(name);
+            //free(name);
             break;
         }
     }
